diff --git a/test/Microsoft.AspNetCore.Server.Kestrel.Core.Tests/KestrelServerLimitsTests.cs b/test/Microsoft.AspNetCore.Server.Kestrel.Core.Tests/KestrelServerLimitsTests.cs
index 60c532c545..bab86a04e7 100644
--- a/test/Microsoft.AspNetCore.Server.Kestrel.Core.Tests/KestrelServerLimitsTests.cs
+++ b/test/Microsoft.AspNetCore.Server.Kestrel.Core.Tests/KestrelServerLimitsTests.cs
@@ -296,7 +296,7 @@ namespace Microsoft.AspNetCore.Server.Kestrel.Core.Tests
public void MinRequestBodyDataRateDefault()
{
Assert.NotNull(new KestrelServerLimits().MinRequestBodyDataRate);
- Assert.Equal(1, new KestrelServerLimits().MinRequestBodyDataRate.BytesPerSecond);
+ Assert.Equal(240, new KestrelServerLimits().MinRequestBodyDataRate.BytesPerSecond);
Assert.Equal(TimeSpan.FromSeconds(5), new KestrelServerLimits().MinRequestBodyDataRate.GracePeriod);
}
diff --git a/src/Microsoft.AspNetCore.Server.Kestrel.Core/KestrelServerLimits.cs b/src/Microsoft.AspNetCore.Server.Kestrel.Core/KestrelServerLimits.cs
index 5eaa4c2c9a..528f78be57 100644
--- a/src/Microsoft.AspNetCore.Server.Kestrel.Core/KestrelServerLimits.cs
+++ b/src/Microsoft.AspNetCore.Server.Kestrel.Core/KestrelServerLimits.cs
@@ -258,8 +258,10 @@ namespace Microsoft.AspNetCore.Server.Kestrel.Core
/// This can be overridden per-request via .
///
///
/// Defaults to 1 byte/second with a 5 second grace period.
///
- public MinDataRate MinRequestBodyDataRate { get; set; } = new MinDataRate(bytesPerSecond: 1, gracePeriod: TimeSpan.FromSeconds(5));
+ public MinDataRate MinRequestBodyDataRate { get; set; } =
+ // Matches the default IIS minBytesPerSecond
+ new MinDataRate(bytesPerSecond: 240, gracePeriod: TimeSpan.FromSeconds(5));
}
}
@@ -258,8 +258,10 @@ namespace Microsoft.AspNetCore.Server.Kestrel.Core
///
///
- /// Defaults to 1 byte/second with a 5 second grace period.
+ /// Defaults to 240 bytes/second with a 5 second grace period.
///